import importlib
import sys

def run_time_analysis(file_name):
    try:
        module = importlib.import_module(file_name)
        functions = [func for func in dir(module) if callable(getattr(module, func))]
        for func_name in functions:
            func = getattr(module, func_name)
            if callable(func):
                print(f"Performing time analysis for {file_name}.{func_name}")
                func()
    except ImportError:
        print(f"{file_name} file not found")

if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Kullanım: timeanalysismoon dosya_adı (uzantısı olmadan)")
        sys.exit(1)

    file_name = sys.argv[1]
    run_time_analysis(file_name)


from setuptools import setup

setup(
    name='timeanalysismoon',
    version='0.8',
    packages=['timeanalysismoon'],
    author='CoderMungan',
    author_email='codermungan@gmail.com',
    description='A time analysis decorator for Python functions',
    long_description='A decorator that measures and prints the execution time of a function.',
    url='https://github.com/CoderMungan/timeanalysismoon',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ],
    entry_points={
        'console_scripts': [
            'timeanalysismoon=timeanalysismoon.cli:main',
        ],
    },
)